# auto-tmux

a tool to automate tmux session configurations. this tool is similar to [tmuxinator](https://github.com/tmuxinator/tmuxinator) but less mature. plus side it is written in a less archaic language.

## TODO

- [ ] consider making publishing to PYPI
  - [ ] if doing so, add automation to github acitons
